@@ -33,9 +33,10 @@
 #  define KCMUTILS_DEPRECATED_NO_EXPORT KCMUTILS_NO_EXPORT KCMUTILS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KCMUTILS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KCMUTILS_NO_DEPRECATED
+#    define KCMUTILS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
